# Application Layer

Application orchestration components: main window, app services, and bootstrap flow.

---

## EzQt_App

::: ezqt_app.app.EzQt_App

---

## AppService

::: ezqt_app.services.application.app_service.AppService

---

## InitService

::: ezqt_app.services.bootstrap.init_service.InitService

---

## InitializationSequence

::: ezqt_app.services.bootstrap.sequence.InitializationSequence

---

## StartupConfig

::: ezqt_app.services.bootstrap.startup_config.StartupConfig
